pub struct BatchEnvelope<P> { /* private fields */ }Expand description
Side metadata for one emitted SQL batch.
Implementations
Sourceimpl<P> BatchEnvelope<P>
impl<P> BatchEnvelope<P>
Sourcepub const fn new(source_position: P, schema_revision: u64) -> Self
pub const fn new(source_position: P, schema_revision: u64) -> Self
Creates a batch envelope from source position metadata and schema revision.
Sourcepub const fn source_position(&self) -> &P
pub const fn source_position(&self) -> &P
Returns the source position metadata.
Sourcepub const fn schema_revision(&self) -> u64
pub const fn schema_revision(&self) -> u64
Returns the schema revision associated with the batch.
Sourcepub fn into_source_position(self) -> P
pub fn into_source_position(self) -> P
Consumes the envelope and returns the source position metadata.