pub enum SqlEvent<T> {
Data(T),
Watermark(Watermark),
Barrier(SqlBarrier),
}Expand description
In-band SQL stream envelope for data and control records.
Variants
Data(T)
User data payload.
Watermark(Watermark)
Event-time progress marker.
Barrier(SqlBarrier)
Checkpoint or alignment marker.
Implementations
Sourceimpl<T> SqlEvent<T>
impl<T> SqlEvent<T>
Sourcepub fn map_data_result<U, F>(self, f: F) -> StreamResult<SqlEvent<U>>where
F: FnOnce(T) -> StreamResult<U>,
pub fn map_data_result<U, F>(self, f: F) -> StreamResult<SqlEvent<U>>where
F: FnOnce(T) -> StreamResult<U>,
Maps only the data branch and passes watermarks and barriers through.
Sourcepub const fn as_watermark(&self) -> Option<Watermark>
pub const fn as_watermark(&self) -> Option<Watermark>
Returns the contained watermark when this event is a watermark.