BatchEnvelope

Struct BatchEnvelope 

pub struct BatchEnvelope<P> { /* private fields */ }
Side metadata for one emitted SQL batch.

Implementations

Source

impl<P> BatchEnvelope<P>

pub const fn new(source_position: P, schema_revision: u64) -> Self

Creates a batch envelope from source position metadata and schema revision.

pub const fn source_position(&self) -> &P

Returns the source position metadata.

pub const fn schema_revision(&self) -> u64

Returns the schema revision associated with the batch.

pub fn into_source_position(self) -> P

Consumes the envelope and returns the source position metadata.